@@ -60,17 +60,17 @@ Selector::Selector(Lum::Model::Int* minutes, Lum::Model::Int *seconds)
   updateAction->Disable();
   removeAction->Disable();
 
-  AttachModel(minutes);
-  AttachModel(seconds);
+  Observe(minutes);
+  Observe(seconds);
 
-  AttachModel(selection);
+  Observe(selection);
 
-  AttachModel(addAction);
-  AttachModel(updateAction);
-  AttachModel(removeAction);
-  AttachModel(okAction);
+  Observe(addAction);
+  Observe(updateAction);
+  Observe(removeAction);
+  Observe(okAction);
 
-  AttachModel(GetClosedAction());
+  Observe(GetClosedAction());
 }
 
 std::wstring Selector::GetTimeString(size_t minutes, size_t seconds) const
